<template>
  <div class="sticky top-0 h-full p-6 bg-[#ebe5ff]" style="height: calc(100% - 10rem);padding-bottom: 4rem;">
    <div class="relative flex justify-between mb-3">
      <div></div>
      <h4 class="font-semibold text-lg mt-3 text-black-600 block whitespace-nowrap">Pilih Daftar Survey</h4>
      <button
      @click="chat.toggleSurvey= !chat.toggleSurvey"
      class="btn btn-ghost btn-circle p-2.5">
        <svg xmlns="http://www.w3.org/2000/svg" class="fill-current text-black-600" viewBox="0 0 24 24">
          <path
              d="M19,6.41L17.59,5L12,10.59L6.41,5L5,6.41L10.59,12L5,17.59L6.41,19L12,13.41L17.59,19L19,17.59L13.41,12L19,6.41Z"/>
        </svg>
      </button>
    </div>

    <div class="block relative h-full m-auto w-auto bg-white rounded-lg">
      <perfect-scrollbar @ps-y-reach-end="onScrollEnd">
        <div class="relative block w-full px-2">
          <div
              v-for="(survey, surveyIndex) in surveyStore.surveys"
              :class="`relative block overflow-hidden mb-3 transition-all duration-200`">
            <div
                :class="`flex gap-6 relative  transition duration-100  hover:bg-gray-100 select-none items-center p-3`">
              <input
                  class="radio radio-primary"
                  type="radio"
                  v-model="selectedSurvey"
                  :value="survey.id"
              >
              <div class="relative block w-full">
                <div class="flex justify-between items-center gap-2">
                  <h3 class="text-md text-gray-700 mb-0">{{ survey.name }}</h3>
                  <div class="flex gap-1 items-center cursor-pointer">
                    <span @click="isOpenSurvey[surveyIndex] = !isOpenSurvey[surveyIndex]">

                      <svg width="20" height="10" viewBox="0 0 22 12" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M1 1.04688L9.65972 10.4938C10.3803 11.28 11.6197 11.28 12.3403 10.4938L21 1.04688" stroke="#626262" stroke-width="1.81818" stroke-linecap="round" stroke-linejoin="round"/>
                      </svg>

                    </span>
                  </div>
                </div>
              </div>
            </div>

            <div
                :class="`relative block transition-all duration-200 ${isOpenSurvey[surveyIndex] ? 'h-auto opacity-100 visible' : 'h-0 opacity-0 invisible'}`">
              <div class="relative p-3 block">
                <div
                    v-for="(attr, index) in survey.attribute"
                    :class="`relative flex gap-6 items-start mb-2`">

                    
                  <div class="w-6 h-6 rounded-full flex justify-center items-center bg-primary text-white">
                    <p class="py-0 my-0">{{index+1}}.</p>
                  </div>
                  <div class="relative block" style="padding-left:1em;">
                    <h4 class="block my-0 text-md font-bold">Pertanyaan</h4>
                    <span class="block text-sm text-gray-500 mb-2">{{ attr.body }}</span>

                    <h4 class="block my-0 text-md font-bold">Type</h4>
                    <span class="block text-sm text-gray-500 mb-3">{{ attr.type }}</span>
                  </div>

                </div>
              </div>
            </div>
          </div>
        </div>
      </perfect-scrollbar>
      <div :class="`absolute transition-all duration-200 ${isListLoading ? 'bottom-2' : '-bottom-20'} w-full  z-40 flex items-center justify-center`">
        <span class="w-7 h-7 bg-white rounded-full shadow-lg flex items-center justify-center">
          <svg class="animate-spin h-full w-full text-scheme-primary" xmlns="http://www.w3.org/2000/svg"
                fill="none" viewBox="0 0 24 24">
          <circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
          <path class="opacity-75" fill="currentColor"
                d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
        </svg>
        </span>
      </div>
    </div>

    
  </div>
  <div class="relative block overflow-hidden h-20 w-full bg-[#ebe5ff]">
      <div
          :class="`${isExpired ? 'disabled cursor-not-allowed' : ''}  relative flex justify-between items-center align-middle h-full`">

        <div class="flex gap-4 items-center w-full h-full py-3 relative px-3">
          <button
              @click="sendSurvey"
              class="right-8 absolute overflow-hidden w-12 h-12 bg-scheme-primary transition duration-300 hover:bg-opacity-80 p-3 rounded-full group"
              id="btn-sendMessage">
            <IcLoading v-if="isLoading"/>
            <IcPaperPlane v-else/>
          </button>
        </div>
      </div>
    </div>
</template>
<script setup lang="ts">

import {useChatListStore} from "../../../stores/chat_list"
import _ from 'lodash'

//@ts-ignore

import {onMounted, onUnmounted, ref} from "vue";
import helpers from "../../../utils/helpers";
import IcLoading from "../../Icon/IcLoading.vue";
import IcPaperPlane from "../../Icon/IcPaperPlane.vue";
import {useSurveyStore} from "../../../stores/surveys";

const isExpired = ref()
const isLoading = ref(false)
const isEndPage = ref(false)
const isListLoading = ref(false)
const currentPage = ref(1)
const chat = useChatListStore()
const selectedSurvey = ref()
const emit = defineEmits(['surveyData'])
const surveyStore = useSurveyStore()
const isOpenSurvey = ref([])
const isFetching = ref(true);

const sendSurvey = async () => {
    isLoading.value = true

    if (selectedSurvey.value != '') {

      const payload = {
        to: chat.detail.customer.phone,
        survey_id: selectedSurvey.value,
      }

      await surveyStore.postSurveys(chat.detail.customer.user_chat_id, payload).then(async (resp) => {
        if ("code" in resp && resp.code == 200) {
          emit('surveyData', resp.data)
          helpers.scrollToBottomChat()
        } else {
          // alert(resp)
        }
      })
    }

    chat.toggleSurvey = false
    isLoading.value = false
}

const onScrollEnd = async (event) => {
  if (isEndPage.value == false && !isFetching.value) {
    let pageNow = currentPage.value + 1
    if (pageNow > 1) {
      isListLoading.value = true
      await surveyStore.getSurveys(pageNow)
      .then((resp) => {
        if (resp.code === 200) {
          if (resp.data.length > 0) {
            resp.data.map((item) => {
              surveyStore.surveys.push(item)
            })
            currentPage.value = pageNow
            isEndPage.value = false
          } else {
            isEndPage.value = true
          }
        }
      })
      isListLoading.value = false
    }
  }
}

onUnmounted(() => {
  chat.toggleSurvey = false
})

onMounted(async () => {
  surveyStore.surveys = []
  await surveyStore.getSurveys()
  .then((resp) => {
    if (resp.code === 200) {
      if (resp.data.length > 0) {
        resp.data.map((item) => {
          surveyStore.surveys.push(item)
        })
      }
    }
  }).finally(()=>{
    isFetching.value = false;
  })
})

</script>
